@@ -1,6 +1,6 @@
 ;;; helm-lib.el --- Helm routines. -*- lexical-binding: t -*-
 
-;; Copyright (C) 2015 ~ 2025  Thierry Volpiatto
+;; Copyright (C) 2015 ~ 2026  Thierry Volpiatto
 
 ;; Author: Thierry Volpiatto
 ;; URL: http://github.com/emacs-helm/helm
@@ -56,6 +56,8 @@
 (declare-function helm-read-file-name "helm-mode.el")
 (declare-function find-function-library "find-func.el")
 (declare-function find-library-name "find-func.el")
+(declare-function cl--describe-class-slots "cl-extra.el")
+(declare-function cl--find-class "cl-macs.el")
 
 (defvar helm-sources)
 (defvar helm-initial-frame)
@@ -459,7 +461,7 @@ Like `this-command' but return the real command, and not
 ;;
 (defun helm-iter-list (seq &optional cycle)
   "Return an iterator object from SEQ.
-The iterator die and return nil when it reach end of SEQ.
+The iterator dies and returns nil when it reaches end of SEQ.
 When CYCLE is specified the iterator never ends."
   (let ((lis seq))
     (lambda ()
@@ -1481,6 +1483,23 @@ If object is a lambda, return \"Anonymous\"."
       (let ((helm-describe-function-function 'describe-function))
         (helm-describe-function (helm-symbolify class))))))
 
+(defun helm-elisp-collect-slots-in-class (class)
+  (with-temp-buffer
+    (cl-letf (((symbol-function 'cl--print-table)
+               #'helm-source--cl--print-table))
+      (cl--describe-class-slots (cl--find-class class))
+      (goto-char (point-min))
+      (cl-loop while (re-search-forward "^\\* \\(.*\\)" nil t)
+               for name = (match-string 1)
+               for doc = (save-excursion
+                           (forward-line 1)
+                           (let ((beg (point))
+                                 (end (when (re-search-forward "^\\*" nil t)
+                                        (1- (match-beginning 0)))))
+                             (when (and beg end)
+                               (buffer-substring beg end))))
+               collect (cons name (concat "* " name "\n" doc))))))
+
 (defun helm-describe-function (func)
   "Display documentation of FUNC, a symbol or string."
   (cl-letf (((symbol-function 'message) #'ignore))
